@@ -20,8 +20,8 @@ C
       external kldistd,lkern
       double precision kldistd,lkern
       integer n1,n2,dv,kern,y(dv,n1,n2),theta(dv,n1,n2),
-     1        thnew(dv,n1,n2)
-      logical aws,fix(n1,n2),mask(n1,n2)
+     1        thnew(dv,n1,n2),fix(n1,n2),mask(n1,n2)
+      logical aws
       double precision bi(n1,n2),bi0,lambda,spmin,wght(dv),hakt,lw(*)
       integer ih,ih1,i1,i2,j1,j2,k,n,
      1        jind,jind2,jwind2,dlw,clw,jw1,jw2
@@ -62,7 +62,7 @@ C$OMP DO SCHEDULE(GUIDED)
       DO i2=1,n2
          DO i1=1,n1
 C            iind=i1+(i2-1)*n1
-            IF (fix(i1,i2)) CYCLE
+            IF (fix(i1,i2).ne.0) CYCLE
 C    nothing to do, final estimate is already fixed by control
             bii=bi(i1,i2)/lambda
 C   scaling of sij outside the loop
@@ -79,7 +79,7 @@ C   scaling of sij outside the loop
                DO jw1=clw-ih1,clw+ih1
                   j1=jw1-clw+i1
                   if(j1.lt.1.or.j1.gt.n1) CYCLE
-                  if(.not.mask(j1,j2)) CYCLE
+                  if(mask(j1,j2).eq.0) CYCLE
                   wj=lw(jw1+jwind2)
                   IF (aws) THEN
               sij=bii*kldistd(theta(1,i1,i2),theta(1,j1,j2),1,wght,dv)
@@ -287,13 +287,13 @@ C
       external kldistgc,lkern
       double precision kldistgc,lkern
       integer n,n1,n2,dv,kern,nvpar,y(dv,n1,n2),theta(dv,n1,n2),
-     1        thnew(dv,n1,n2)
-      logical aws,fix(n),early,homogen,fixi
+     1        thnew(dv,n1,n2),fix(n),early,homogen
+      logical aws
       double precision bi(n),lambda,spmin,hakt,lw(*),wghts(dv),bi0,
      1       vcoef(nvpar,dv),chcorr(*),meanvar(dv),hhom(n),
      2       thi(3),thij(3),si(3),s2i(9),swjy(3)
       integer ih,ih1,ii,i1,i2,j1,j2,ja1,je1,l,k,info,kdv,
-     1        jind,jind2,jwind2,dlw,clw,jw1,jw2,m0
+     1        jind,jind2,jwind2,dlw,clw,jw1,jw2,m0,fixi
       double precision bii,sij,swj,z1,z2,wj,hakt2,spf,
      1       swj0,hhomi,hhommax,hfixmax,hnfix,hmax2
 C  s2i, s2ii temporay stor sigma^2_i and its inverse (nneded for KL-distance)
@@ -308,7 +308,7 @@ C  maximaum dv = 4
 C      n=n1*n2
 C   compute location weights first
       swj0=0.d0
-      fixi=.FALSE.
+      fixi=0
       hmax2=0.d0
       DO j2=1,dlw
          z2=clw-j2
@@ -343,14 +343,14 @@ C$OMP DO SCHEDULE(GUIDED)
          i1=mod(ii,n1)
          if(i1.eq.0) i1=n1
          i2=(ii-i1)/n1+1
-         if(early) fixi=fix(ii)
-         if(fixi) THEN
+         if(early.ne.0) fixi=fix(ii)
+         if(fixi.ne.0) THEN
             DO k=1,dv
                thnew(k,i1,i2)=theta(k,i1,i2)
             END DO
             CYCLE
          END IF
-         if(homogen) THEN
+         if(homogen.ne.0) THEN
             hhomi=hhom(ii)
             hhomi=hhomi*hhomi
          END IF
@@ -415,13 +415,13 @@ C  Now fill estimated Covariancematrix in pixel i
                IF (aws.and.z1.ge.hhomi) THEN
                   sij=bii*kldistgc(thij,s2i,dv)
                   IF (sij.gt.1.d0) THEN
-                     if(homogen) hhommax=min(hhommax,z1)
+                     if(homogen.ne.0) hhommax=min(hhommax,z1)
                      CYCLE
                   END IF
-                  if(early) hfixmax=max(hfixmax,z1)
+                  if(early.ne.0) hfixmax=max(hfixmax,z1)
                   IF (sij.gt.spmin) THEN
                      wj=wj*(1.d0-spf*(sij-spmin))
-                     if(homogen) hhommax=min(hhommax,z1)
+                     if(homogen.ne.0) hhommax=min(hhommax,z1)
                   END IF
                END IF
                swj=swj+wj
@@ -434,9 +434,9 @@ C  Now fill estimated Covariancematrix in pixel i
             thnew(k,i1,i2)=int(swjy(k)/swj)
          END DO
          bi(ii)=swj
-         if(homogen) hhom(ii)=sqrt(hhommax)
-         IF(early.and.hakt-sqrt(hfixmax).ge.hnfix) THEN
-            fix(ii)=.TRUE.
+         if(homogen.ne.0) hhom(ii)=sqrt(hhommax)
+         IF(early.ne.0.and.hakt-sqrt(hfixmax).ge.hnfix) THEN
+            fix(ii)=1
          END IF
       END DO
 C$OMP END DO NOWAIT
